Monty Python's Flying Circus: Just the Words - Episode 33

# Episode Thirty-three

Biggles dictates a letter
Climbing the north face of the Uxbridge Road
Lifeboat
Old lady snoopers
'Storage jars'
The show so far
Cheese shop
Philip Jenkinson on Cheese Westerns
Sam Peckinpah's 'Salad Days'
Apology
The news with Richard Baker
Seashore interlude film

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A light comes up on an organ in the centre of a concert-hall stage. Applause. The organist with wild hair (Terry J) appears from left. He walks fully clothed across to the organ looking pleased with himself. He sits at the organ and raises his hands...his clothes fly up in the air so that, as per normal, he is naked. He plays the usual chords. Cut on the last note to a naked quartet with identical grins, fright wigs and blacked-out teeth staring maniacally at the camera.
Announcer | And now...
It's Man | It's...
| Animated titles.
Voice Over | Monty Python's Flying Circus.
| Cut to stock film of First World War fighter planes in a dog-fight. Heroic war music.
Voice Over | The Adventures of Biggles. Part one - Biggles dictates a letter.
| Mix through to Biggles and secretary in an office.
Biggles | Miss Bladder, take a letter.
Secretary (Nicki Howorth) | Yes, Señor Biggles.
Biggles | Don't call me señor! I'm not a Spanish person. You must call me Mr Biggles, or Group Captain Biggles or Mary Biggles if I'm dressed as my wife, but never señor.
Secretary | Sorry.
Biggles | I've never even been to Spain.
Secretary | You went to Ibiza last year.
Biggles | That's still not grounds for calling me señor, or Don Beeg-les for that matter. Right, Dear King Haakon...
Secretary | Of Norway, is that?
Biggles | Just put down what I say.
Secretary | Do I put that down?
Biggles | Of course you don't put that down.
Secretary | Well what about that?
Biggles | Look. (she types) Don't put that down. Just put down - wait a mo - wait a mo. (puts on antlers) Now, when I've got these antlers on - when I've got these antlers on I am dictating and when I take them off (takes them off) I am not dictating.
Secretary | (types) I am not dictating.
Biggles | What? (she types; puts the antlers on) Read that back.
Secretary | Dear King Haakon, I am not dictating what?
Biggles | No, no, no, you loopy brothel inmate.
Secretary | I've had enough of this. I am not a courtesan. (moves round to front of the desk, sits on it and crosses her legs provocatively)
Biggles | Oh, oh, 'courtesan', oh aren't we grand. Harlot's not good enough for us eh? Paramour, concubine, fille de joie. That's what we are not. Well listen to me my fine fellow, you are a bit of tail, that's what you are.
Secretary | I am not, you demented fictional character.
Biggles | Algy says you are. He says you're no better than you should be.
Secretary | And how would he know?
Biggles | And just what do you mean by that? Are you calling my old fictional comrade-in-arms a fairy?
Secretary | Fairy! Poof's not good enough for Algy, is it? He's got to be a bleedin' fairy. Mincing old RAF queen. (sits at the desk)
Biggles | (into the intercom) Algy, I have to see you.
Algy | Right ho. (he enters) What ho everyone.
Biggles | Are you gay?
Algy | I should bally well say so, old fruit.
Biggles | Ugh! (he shoots him) Dear King Haakon ... oh ... (takes the antlers off) Dear King Haakon. (the secretary types) Just a line to thank you for the eels. Mary thought they were really scrummy, comma, so did I full stop. I've just heard that Algy was a poof, exclamation mark. What would Captain W. E. Johns have said, question mark. Sorry to mench, but if you've finished with the lawn-edger could you pop it in the post. Love Biggles, Algy deceased and Ginger. Ginger! (puts the antlers on)
Secretary | What?
Biggles | Rhyming slang - ginger beer.
Secretary | Oh.
Biggles | (into the intercom) Ginger.
Ginger | Hello, sweetie.
Biggles | I have to see you.
| The door opens, Ginger enters as a terrible poof in camp flying gear, sequins, eye make-up, silver stars on his cheeks.
Ginger | Yes, Biggles?
Biggles | Are you a poof
Ginger | (camp outrage) I should say not.
Biggles | Thank God for that. Good lad. (Ginger exits) Stout fellow, salt of the earth, backbone of England. Funny, he looks like a poof. (takes off the antlers) Dear Princess Margaret.
| Pantomime Princess Margaret enters from cupboard.
Margaret | Hello.
Biggles | Get back in the cupboard you pantomimetic royal person. (she goes)
| Quick cut to a loony.
Loony | Lemon curry?
| Cut back to Biggles.
Biggles | Dear real Princess Margaret, thank you for the eels, full stop. They were absolutely delicious and unmistakably regal, full stop. Sorry to mench but if you've finished with the hairdryer could you pop it in the post? Yours fictionally Biggles, Oh, PS see you at the Saxe-Coburgs' canasta evening. (puts the antlers on) That should puzzle her.
Secretary | (sexily) Si Señor Biggles.
Biggles | Silence, naughty lady of the night!
| Bring up heroic music and mix through to stock film of fighter planes in dog-fight.
Voice Over | Next week part two - 'Biggles Flies Undone'.
| Then a very noisy and violent animation sketch.
Voice Over | Meanwhile not very far away.
| Cut to mountain climbers, with all the accoutrements: ropes, carabino's, helmets, pitons, hammers, etc. They are roped together, apparently climbing a mountain.
Voice Over | Climbing. The world's loneliest sport, where hardship and philosophy go hand in glove. And here, another British expedition, attempting to be the first man to successfully climb the north face of the Uxbridge Road. (Pull out to reveal that they are climbing along a wide pavement; a shopper pushing a pram comes into shot) This four-man rope has been climbing tremendously. BBC cameras were there to film every inch.
| Cut to a BBC cameraman clinging to a lamppost, filming. He is wearing climbing gear too. Cut to papier mache model of the Uxbridge Road, with the route all neatly marked out in white, and various little pins for the camps.
Chris | (voice over) The major assault on the Uxbridge Road has been going on for about three weeks, really ever since they established base camp here at the junction of Willesden Road, and from there they climbed steadily to establish camp two, outside Lewis's, and it's taken them another three days to establish camp three, here outside the post office. (cut to a pup tent being firmly planted on the side of a large post-box; it has a little union jack on it.) Well they've spent a good night in there last night in preparation for the final assault today. The leader of the expedition is twenty-nine-year-old Bert Tagg - a local headmaster and mother of three.
| Cut to Bert crawling along the pavement. The interviewer is crouching down beside him.
Interviewer | Bert. How's it going?
Bert | Well, it's a bit gripping is this, Chris. (heavy breathing interspersed) I've got to try and reach that bus stop in an hour or so and I'm doing it by... (rearranging rope) damn ... I'm doing it, er, by laying back on this gutter so I'm kind of guttering and laying back at the same time, and philosophizing.
Interviewer | Bert, some people say this is crazy.
Bert | Aye, well but they said Crippen was crazy didn't they?
Interviewer | Crippen was crazy.
Bert | Oh, well there you are then. (shouts) John, I'm sending you down this carabiner on white. (there is a white rope between Bert and John)
| Quick cut to Viking.
Viking | Lemon curry?
| Cut back to the street.
Bert | Now you see he's putting a peg down there because I'm quite a way up now, and if I come unstuck here I go down quite a long way.
Interviewer | (leaving him) Such quiet courage is typical of the way these brave chaps shrug off danger. Like it or not, you've got to admire the skill that goes into it.
| By the miracle of stop action, they all fall off the road, back down the pavement. Passers-by, also in stop action, walk by normally, ignoring the fall. Cut to an ordinary kitchen. A Mrs Pinnet type lady with long apron and headscarf is stuffing a chicken with various unlikely objects. The door opens. Sound of rain, wind and storm outside. A liftboatman enters, soaked to the skin. He shuts the door.
First Lifeboatman | (taking off his sou'wester and shaking the water off it) Oh it's terrible up on deck.
Mrs Neves | Up on deck?
First Lifeboatman | Yes on deck. It's diabolical weather.
Mrs Neves | What deck, dear?
First Lifeboatman | The deck, The deck of the lifeboat.
Mrs Neves | This isn't a lifeboat, dear. This is 24, Parker Street.
First Lifeboatman | This is the Newhaven Lifeboat.
Mrs Neves | No it's not, dear.
| The First Lifeboatman puts on his sou'wester, goes over to the back door and opens it, He peers out. Sound of wind and lashing rain. Cut to the back door at the side of a suburban home, the lifeboatman looking out over the lawns, flowers and windless, rainless calm across to similar neat suburban houses. The noise cuts. The liftboatman withdraws his head from the door. Sound of wind and rain again which cease abruptly as he withdraws his head and shuts the door.
First Lifeboatman | You're right. This isn't a lifeboat at all.
Mrs Neves | No, I wouldn't live here if it was,
First Lifeboatman | Do you mind if I sit down for a minute and collect my wits?
Mrs Neves | No, you do that, I'll make you a nice cup of tea.
First Lifeboatman | Thanks very much.
| The door flies open. More sound of wind and rain. Two other rain-soaked lifeboatmen appear.
Second Lifeboatman | Oooh, it's a wild night up top.
Third Lifeboatman | Your turn on deck soon, Charlie.
First Lifeboatman | It's not a lifeboat, Frank.
Third Lifeboatman | What?
Second Lifeboatman | What do you mean?
First Lifeboatman | It's not a lifeboat. It's this lady's house.
| The two lifeboatmen look at each other, then turn and open the door. Sound of wind and rain as usual. They peer out. Cut to the back door - the two lifeboatmen are peering out. They shout.
Second and Third Lifeboatmen | Captain! Captain! Ahoy there! Ahoy there! Captain!!
| Their voices carry over the following shot or two. Cut to reverse angle of window across the road. A net curtain moves and an eye peers out. We still hear the shouts. Close up on an elderly spinster (Gladys) holding the net curtain discreetly ajar.
Enid | Who's that shouting?
| We pull out to reveal a sitting room full of high-powered eavesdropping equipment, i.e. an enormous telescope on wheels with a controller's chair attached to it, several subsidiary telescopes pointing out of the window, radar scanners going round and round, two computers with flashing lights, large and complex tape and video recorders, several TV monitors, oscilloscopes, aerials, etc. All these have been squeezed in amongst the furniture of two retired middle-class old ladies. Enid, a dear old lady with a bun, sits at the control seat of an impressive-looking console, pressing buttons. She also has some knitting.
Gladys | It's a man outside Number 24.
Enid | Try it on the five inch, Gladys.
Gladys | (looking at the array of telescopes) I can't. I've got that fixed on the Baileys at Number 13. Their new lodger moves in today.
Enid | All fight, hold 13 on the five-inch and transfer the Cartwrights to the digital scanner.
| Gladys leaps over to the tape deck, presses levers and switches. Sound of tape reversing. There is a hum and lights flash on and off. A blurred image of a lady in the street comes up on one of the monitors.
Enid | Hold on, Mrs Pettigrew's coming back from the doctor's.
Gladys | All right, bring her up on two. What's the duration reading on the oscillator?
Enid | 48.47.
Gladys | Well that's a long time for someone who's just had a routine checkup.
Enid | (reading a graph on a computer) Yes, her pulse rate's 146!
Gladys | Zoom in on the 16mm and hold her, Enid.
Enid | Roger, Gladys.
Gladys | I'll try and get her on the twelve-inch. (she dips into the control seat of the huge mobile telescope; we cut to the view through Gladys's telescope - out of focus at first, but then sharper as she zooms in towards the side door of Number 24) Move the curtain, Enid. (the curtain is opened a little) Thank you, love.
| Cut to the interior of Mrs Neves's kitchen once again. It is absolutely full of lifeboatmen. They are all talking happily and drinking cups of tea. We pick up the conversation between two them.
First Lifeboatman | Yes, it's one of those new self-righting models. Newhaven was about the first place in the country to get one.
Second Lifeboatman | What's the displacement on one of them jobs then?
First Lifeboatman | Oh it's about 140-150 per square inch.
Mrs Neves | Who's for fruit cake?
All | Oh yes, please, please.
Mrs Neves | Yes, right, macaroons, that's two dozen fruit cakes, half a dozen macaroons. Right ho. Won't be a jiffy then.
| She puts a scarf on, picks up a basket and goes out of the front door. As she opens door, we hear the sound of a storm which carries us into the next shot. Cut to the deck of a lifeboat; rain-lashed, heaving, wind-tossed Mrs Neves struggles against the gale force winds along the deck. She hammers on a hatch in the forward part of the lifeboat.
Mrs Neves | Yoohoo! Mrs Edwards!
| The hatch opens and a cosy shop-keeping pepperpot sticks her head out.
Mrs Edwards | Hello.
Mrs Neves | Hello, two dozen fruit cakes and half a dozen macaroons.
Mrs Edwards | Sorry love, no macaroons. How about a nice vanilla sponge?
Mrs Neves | Yes, that'll be lovely.
Mrs Edwards | Right ho. (sound of a ship's horn; they both look) There's that nice herring trawler come for their Kup Kakes. Excuse me. (she produces a loudhailer) Hello, Captain Smith?
Voice | Hallooooo!
| Mrs Edwards hurls a box of Kup Kakes off deck.
Mrs Edwards | Kup Kakes to starboard.
Voice | Coming.
Mrs Neves | I'll pay you at the end of the week, all right?
Mrs Edwards | OK, right ho.
| Mrs Neves struggles back along the deck. Cut to stock film of Ark Royal in a storm.
Mrs Neves | Here; it's the Ark Royal, Doris. Have you got their rock buns ready?
| Sound of a ship's horn.
Mrs Edwards | Hang on!
| Doris appears at the hatch, and hands over two cake boxes.
Doris | Here we are, five for them and five for HMS Eagle.
Mrs Edwards | Right ho..(takes them and throws them both overboard; an officer climbs up the side of the boat) Yes?
Officer | HMS Defiant? Two set teas please.
Mrs Edwards | Two set teas, Doris. Forty-eight pence. There we are, thank you.
| Money is handed over. The teas emerge on two little trays with delicate crockery, little teapots, milk jugs, etc.
Officer | By the way, do you do lunches?
Mrs Edwards | No, morning coffee and teas only.
Officer | Right ho. (holding the teas he goes up to edge and jumps overboard)
| Cut to very quick series of stills of storage jars.
| CAPTION: 'STORAGE JARS'
| Urgent documentary music. Mix through to an impressive documentary set. Zoom in to presenter in a swivel chair. He swings around to face the camera.
Presenter | Good evening and welcome to another edition of 'Storage Jars'. On tonight's programme Mikos Antoniarkis, the Greek rebel leader who seized power in Athens this morning, tells us what he keeps in storage jars. (quick cut to photo of a guerrilla leader with a gun; sudden dramatic chord; instantly cut back to the presenter) From strife-torn Bolivia, Ronald Rodgers reports on storage jars there. (still of a Bolivian city and again dramatic chord and instantly back to the presenter) And closer to home, the first dramatic pictures of the mass jail-break near the storage jar factory in Maidenhead. All this and more in 'Storage Jars'!
| Cut to a road in front of a heap of smouldering rubble. Dull thuds of mortars. Reporter in short sleeves standing in tight shot. Explosions going off behind him at intervals.
Rodgers | This is La Paz, Bolivia, behind me you can hear the thud of mortars and the high-pitched whine of rockets, as the battle for control of this volatile republic shakes the foundations of this old city. (slowly we pull out during this until we see in front of him a fairly long trestle table set out with range of diffrent-sized storage jar) But whatever their political inclinations these Bolivians are all keen users of storage jars. (the explosions continue behind him) Here the largest size is used for rice and for mangoes - a big local crop. Unlike most revolutionary South American states they've an intermediary size in between the 2 lb and 5 lb jars. This gives this poor but proud people a useful jar for apricots, plums and stock cubes. The smallest jar - this little 2oz jar, for sweets, chocolates and even little shallots. No longer used in the West it remains here as an unspoken monument to the days when La Paz knew better times. Ronald Rodgers, 'Storage Jars', La Paz.
| ANIMATION: television is bad for your eyes.
Voice Over | (and CAPTION:) 'THE SHOW SO FAR'
| Cut to a man sitting at a desk with a script.
Mr Tussaud | Hello, the, er, show so far...well it all started with the organist losing all his clothes as he sat down at the organ, and after this had happened and we had seen the titles of the show, we saw Biggles dictating a letter to his secretary, who thought he was Spanish, and whom he referred to as a harlot and a woman of the night, although she preferred to be called a courtesan. Then we saw some people trying to climb a road in Uxbridge. And then there were some cartoons and then some lifeboatmen came into a woman's sitting room and after a bit the woman went out to buy some cakes on a lifeboat and then a naval officer jumped into the sea. Then we saw a man telling us about storage jars from Bolivia, then there were some more cartoons and a man told us about what happened on the show so far and a great hammer came down and hit him on the head. (he frowns) I don't remember that? (a big hammer hits him on the head)
| Quick cut to 'It's' man.
It's Man | Lemon curry?
| A montage of photographs. The cutting from photo to photo is pretty fast. Greek music is heard. Starting with: a close up of Mousebender, who is respectable and wears smart casual clothes; various photos of Mousebender walking along the pavement, again very artily shot from show-off angles; Mousebender pausing outside a shop; Mousebender looking up at the shop; Edwardian-style shop with large sign above it reading 'Ye Olde Cheese Emporium'; another sign below the first reading 'Henry Wensleydale, Purveyor of Fine Cheese to the Gentry and the Poverty Stricken Too'; another sign below this reading 'Licensed for Public Dancing'; close up of Mousebender looking pleased; shot of Mousebender entering the shop. Music cuts dead. Cut to interior of the cheese shop. Greek music playing as Mousebender enters. Two men dressed as city gents are Greek dancing in the corner to the music of a bouzouki. The shop itself is large and redolent of the charm and languidity of a bygone age. There is actually no cheese to be seen either on or behind the counter but this is not obvious. Mousebender approaches the counter and rings a small handbell. Wensleydale appears.
Wensleydale | Good morning, sir.
Mousebender | Good Morning. I was sitting in the public library on Thurmon Street just now, skimming through 'Rogue Herries' by Horace Walpole, when suddenly I came over all peckish.
Wensleydale | Peckish, sir?
Mousebender | Esurient.
Wensleydale | Eh?
Mousebender | (broad Yorkshire) Eee I were all hungry, like!
Wensleydale | Oh, hungry.
Mousebender | (normal accent) In a nutshell. So I thought to myself, 'a little fermented curd will do the trick'. So I curtailed my Walpolling activites, sallied forth and infiltrated your place of purveyance to negotiate the vending of some cheesy comestibles. (smacks his lips)
Wensleydale | Come again.
Mousebender | (broad nothern accent) I want to buy some cheese.
Wensleydale | Oh, I thought you were complaining about the music!
Mousebender | (normal voice) Heaven forbid. I am one who delights in all manifestations of the terpsichorean muse.
Wensleydale | Sorry?
Mousebender | I like a nice dance - you're forced to.
| Quick cut to a Viking.
Viking | (broad Northern accent) Anyway.
| Cut back to cheese shop.
Wensleydale | Who said that?
Mousebender | (normal voice) Now my good man, some cheese, please.
Wensleydale | Yes certainly, sir. What would you like?
Mousebender | Well, how about a little Red Leicester.
Wensleydale | I'm, afraid we're fresh out of Red Leicester, sir.
Mousebender | Oh, never mind. How are you on Tilsit?
Wensleydale | Never at the end of the week, sir. Always get it fresh first thing on Monday.
Mousebender | Tish tish. No matter. Well, four ounces of Caerphilly, then, if you please, stout yeoman.
Wensleydale | Ah well, it's been on order for two weeks, sir, I was expecting it this morning.
Mousebender | Yes, it's not my day, is it? Er, Bel Paese?
Wensleydale | Sorry.
Mousebender | Red Windsor?
Wensleydale | Normally, sir, yes, but today the van broke down.
Mousebender | Ah. Stilton?
Wensleydale | Sorry.
Mousebender | Gruyere? Emmental?
Wensleydale | No.
Mousebender | Any Norwegian Jarlsberger?
Wensleydale | No.
Mousebender | Liptauer?
Wensleydale | No.
Mousebender | Lancashire?
Wensleydale | No.
Mousebender | White Stilton?
Wensleydale | No.
Mousebender | Danish Blue?
Wensleydale | No.
Mousebender | Double Gloucester?
Wensleydale | ...No.
Mousebender | Cheshire?
Wensleydale | No.
Mousebender | Any Dorset Blue Vinney?
Wensleydale | No.
Mousebender | Brie, Roquefort, Pont-l'Évêque, Port Salut, Savoyard, Saint-Paulin, Carre-de-L'Est, Boursin, Bresse-Bleu, Perle de Champagne, Camenbert?
Wensleydale | Ah! We do have some Camembert, sir.
Mousebender | You do! Excellent.
Wensleydale | It's a bit runny, sir.
Mousebender | Oh, I like it runny.
Wensleydale | Well as a matter of fact it's very runny, sir.
Mousebender | No matter. No matter. Hand over le fromage de la Belle France qui s'apelle Camembert, s'il vous plaît.
Wensleydale | I think it's runnier than you like it, sir.
Mousebender | (smiling grimley) I don't care how excrementally runny it is. Hand it over with all speed.
Wensleydale | Yes, sir. (bends below counter and reappears) Oh...
Mousebender | What?
Wensleydale | The cat's eaten it.
Mousebender | Has he?
Wensleydale | She, sir.
Mousebender | Gouda?
Wensleydale | No.
Mousebender | Edam?
Wensleydale | No.
Mousebender | Caithness?
Wensleydale | No.
Mousebender | Smoked Austrian?
Wensleydale | No.
Mousebender | Sage Darby?
Wensleydale | No, sir.
Mousebender | You do have some cheese, do you?
Wensleydale | Certainly, sir. It's a cheese shop, sir. We've got...
Mousebender | No, no, no, don't tell me. I'm keen to guess.
Wensleydale | Fair enough.
Mousebender | Wensleydale.
Wensleydale | Yes, sir?
Mousebender | Splendid. Well, I'll have some of that then, please.
Wensleydale | Oh, I'm sorry sir, I thought you were reffering to me, Mr Wensleydale.
Mousebender | Gorgonzola?
Wensleydale | No.
Mousebender | Parmesan?
Wensleydale | No.
Mousebender | Mozzarella?
Wensleydale | No.
Mousebender | Pippo Crème?
Wensleydale | No.
Mousebender | Any Danish Fynbo?
Wensleydale | No.
Mousebender | Czechoslovakian Sheep's Milk Cheese?
Wensleydale | No.
Mousebender | Venezuelan Beaver Cheese?
Wensleydale | Not today sir, no.
| (pause)
Mousebender | Well let's keep it simple, how about Cheddar?
Wensleydale | Well, I'm afraid we don't get much call for it around these parts.
Mousebender | Not call for it? It's the single most popular cheese in the world!
Wensleydale | Not round these parts, sir.
Mousebender | And pray what is the most popular cheese round these parts?
Wensleydale | Ilchester, sir.
Mousebender | I see.
Wensleydale | Yes, sir. It's quite staggeringly popular in the manor, squire.
Mousebender | Is it.
Wensleydale | Yes sir, it's our number-one seller.
Mousebender | Is it.
Wensleydale | Yes sir.
Mousebender | Ilchester, eh?
Wensleydale | Right.
Mousebender | OK, I'm game. Have you got any, he asked, expecting the answer no?
Wensleydale | I'll have a look, sir...nnnnnnooooooooo.
Mousebender | It's not much of a cheese shop really, is it?
Wensleydale | Finest in the district, sir.
Mousebender | And what leads you to that conclusion?
Wensleydale | Well, it's so clean.
Mousebender | Well, it's certainly uncontaminated by cheese.
Wensleydale | You haven't asked me about Limberger, sir.
Mousebender | Is it worth it?
Wensleydale | Could be.
Mousebender | OK, have you...will you shut that bloody dancing up! (the music stops)
Wensleydale | (to dancers) Told you so.
Mousebender | Have you got any Limberger?
Wensleydale | No.
Mousebender | No, that figures. It was pretty predictable, really. It was an act of purest optimism to pose the question in the first place. Tell me something, do you have any cheese at all?
Wensleydale | Yes, sir.
Mousebender | Now I'm going to ask you that question once more, and if you say 'no' I'm going to shoot you through the head. Now, do you have any cheese at all?
Wensleydale | No.
Mousebender | (shoots him) What a senseless waste of human life.
| Mousebender puts a cowboy hat on his head. Cut to stock shot of man on horse riding into the sunset. Music swells dramatically.
| CAPTION: 'ROGUE CHEDDAR (1967)' CAPTION: 'FIN'
| Ordinary simple Philip Jenkinson at a desk set as seen in Monty Python's Flying Circus. Philip Jenkinson sits simpering and pouting like a cross between Truman Capote and a pederast vole.
Philip Jenkinson | Horace Walpole's 'Rogue Cheddar', (sniff) one of the first of the Cheese Westerns to be later followed by 'Gunfight at Gruyère Corral', 'Ilchester 73', and 'The Cheese Who Shot Liberty Valence'. While I'm on the subject of Westerns, I want to take a closer look at one of my favourite film directors, Sam Peckinpah, the expatriate from Fresno, California.
| SUPERIMPOSED CAPTION: 'GET ON WITH IT'
Philip Jenkinson | In his earliest films, 'Major Dundee', (sniff)
| SUPERIMPOSED CAPTION: 'AND STOP SNIFFING'
Philip Jenkinson | 'The Wild Bunch' and 'Straw Dogs' he showed his predilection for the utterly truthful and very sexually arousing portrayal of violence (sniff) in its starkest form. (sniff)
| SUPERIMPOSED CAPTION: 'WILL YOU STOP SNIFFING'
Philip Jenkinson | In his latest film Peckinpah has moved into the calmer and more lyrical waters of Julian Slade's, 'Salad Days'.
| Lyrical scene of boys in white flannels and girls in pretty dresses frolicking on a lawn to the accompaniment of a piano played by one of the boys.
| SUPERIMPOSED CAPTION: 'SALAD DAYS (1971) DIRECTOR SAM PECKINPAH'
| The boys and girls cease frolicking and singing. Lionel enters holding a tennis racket.
Lionel | Hello everybody.
All | Hello Lionel.
Lionel | I say what a simply super day.
All | Gosh yes.
Woman | It's so, you know, sunny.
Lionel | Yes isn't it? I say anyone for tennis?
Julian | Oh super!
Charles | What fun.
Julian | I say, Lionel, catch.
| He throws the tennis ball to Lionel. It hits Lionel on the head. Lionel claps one hand to his forehead. He roars in pain as blood seeps through his fingers.
Lionel | Oh gosh.
| He tosses his racket out of frame and we hear a hideous scream. The camera pans to pick up a pretty girl in summer frock with the handle of the racket embedded in her stomach. Blood is pouring out down her dress.
Woman | Oh crikey.
| Spitting blood out of her mouth she collapses onto the floor clutching at Charles's arm. The arm comes off. Buckets of blood burst out of the shoulder drenching the girl and anyone else in the area. He staggers backwards against the piano. The piano lid drops, severing the pianist's hands. The pianist screams. He stands, blood spurting from his hands over piano music. The piano collapses in slow motion, shot from several angles simultaneously as per 'Zabriskie Point'. Intercut terrified faces of girls screaming in slow motion. The piano eventually crushes them to death; an enormous pool of blood immediately swells up from beneath piano where the girls are. We see Julian stagger across the frame with the piano keyboard through his stomach. As he turns the end of the keyboard knocks off the head of a terrified girl who is sitting on the grass nearby. A volcanic quantity of blood geysers upwards. Pull out and upward from this scene as the music starts again. Cut back to Philip Jenkinson.
Philip Jenkinson | Pretty strong meat there from (sniff) Sam Peckinpah.
| There is the sound of a burst of machine-gun fire and holes appear in Philip Jenkinson's shirt. Blood spurting from each hole in slow motion. Intercut shots from different angles.
| CAPTION: 'TEE HEE'
| Roll credits over Jenkinson's dying agonies. Fade out.
Voice Over | (and Roller Caption) 'THE BBC WOULD LIKE TO APOLOGIZE TO EVERYONE IN THE WORLD FOR THE LAST ITEM. IT WAS DISGUSTING AND BAD AND THOROUGHLY DISOBEDIENT AND PLEASE DON'T BOTHER TO PHONE UP BECAUSE WE KNOW IT WAS VERY TASTELESS, BUT THEY DIDN'T REALLY MEAN IT AND THEY DO ALL COME FROM BROKEN HOMES AND HAVE VERY UNHAPPY PERSONAL LIVES, ESPECIALLY ERIC. ANYWAY, THEY'RE REALLY VERY NICE PEOPLE UNDERNEATH AND VERY WARM IN THE TRADITIONAL SHOW BUSINESS WAY AND PLEASE DON'T WRITE IN EITHER BECAUSE THE BBC IS GOING THROUGH AN UNHAPPY PHASE AT THE MOMENT - WHAT WITH ITS FATHER DYING AND THE MORTGAGE AND BBC 2 GOING OUT WITH MEN.'
Voice Over | (and Roller Caption): 'THE BBC WOULD LIKE TO DENY THE LAST APOLOGY. IT IS VERY HAPPY AT HOME AND BBC 2 IS BOUND TO GO THROUGH THIS PHASE, SO FROM ALL OF US HERE GOOD NIGHT, SLEEP WELL, AND HAVE AN ABSOLUTELY SUPER DAY TOMORROW, KISS, KISS.'
| Cut to Richard Baker sitting at the traditional news desk.
Richard Baker | We've just heard that an explosion in the kitchens of the House of Lords has resulted in the breakage of seventeen storage jars. Police ruled out foul play. (pause) Lemon curry?
| Fade out. Fade up on film of seashore, waves breaking on beach.
| SUPERIMPOSED CAPTION: 'INTERLUDE'
| The film goes on for quite a long time. Eventually, the announcer, dressed in medieval Spanish soldier's costume, walks into shot.
Announcer | (to camera) Um, I'm sorry about the ... the, er, pause, only I'm afraid the show is a couple of minutes short this week. You know, sometimes the shows aren't really quite as er, long as they ought to be. (pause, he looks round at the sea) Beautiful, isn't it. (he walks out of shot; long pause; he walks back) Look there's not really a great deal of point in your, sort of hanging on at your end, because I'm afraid there aren't any more jokes or anything.
| He walks out of shot. We stay with the film for quite a long time before we finally fade out.